==> commerce_tip-1.0.0.tar.gz: commerce_tip/src/Plugin/Commerce/CheckoutPane/TipCheckoutPane.php <==
<?php

namespace Drupal\commerce_tip\Plugin\Commerce\CheckoutPane;

use Drupal\commerce\InlineFormManager;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the commerce tip checkout pane.
 *
 * @CommerceCheckoutPane(
 *   id = "commerce_tip_checkout_pane",
 *   label = @Translation("Tip"),
 *   default_step = "order_information",
 *   wrapper_element = "fieldset",
 * )
 */
class TipCheckoutPane extends CheckoutPaneBase {

  /**
   * The inline form manager.
   *
   * @var \Drupal\commerce\InlineFormManager
   */
  protected InlineFormManager $inlineFormManager;

  /**
   * Constructs a new CouponRedemption object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface $checkout_flow
   *   The parent checkout flow.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\commerce\InlineFormManager $inline_form_manager
   *   The inline form manager.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow, EntityTypeManagerInterface $entity_type_manager, InlineFormManager $inline_form_manager) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $checkout_flow, $entity_type_manager);

    $this->inlineFormManager = $inline_form_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $checkout_flow,
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.commerce_inline_form')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationSummary() {
    $summary = [];
    if (empty($this->configuration['tip_description']['value'])) {
      $summary[] = $this->t('Tip description: Off');
    }
    else {
      $summary[] = $this->t('Tip description: On');
    }

    return implode('<br>', $summary);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'tip_description' => [
        'value' => '',
        'format' => 'plain_text',
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['tip_description'] = [
      '#type' => 'text_format',
      '#title' => t('Tip Description'),
      '#description' => t('Shown at the top of checkout pane.'),
      '#default_value' => $this->configuration['tip_description']['value'],
      '#format' => $this->configuration['tip_description']['format'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['tip_description'] = $values['tip_description'];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $configuration = [
      'order_id' => $this->order->id(),
      'tip_description' => $this->configuration['tip_description'],
    ];
    $inline_form = $this->inlineFormManager->createInstance('commerce_tip_inline_form', $configuration);
    $pane_form['form'] = [
      '#parents' => array_merge($pane_form['#parents'], ['form']),
    ];
    $pane_form['form'] = $inline_form->buildInlineForm($pane_form['form'], $form_state);

    return $pane_form;
  }

}

==> commerce_tip-1.0.1.tar.gz: commerce_tip/src/Plugin/Commerce/CheckoutPane/TipCheckoutPane.php <==
<?php

namespace Drupal\commerce_tip\Plugin\Commerce\CheckoutPane;

use Drupal\commerce\InlineFormManager;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface;
use Drupal\commerce_checkout\Plugin\Commerce\CheckoutPane\CheckoutPaneBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides the commerce tip checkout pane.
 *
 * @CommerceCheckoutPane(
 *   id = "commerce_tip_checkout_pane",
 *   label = @Translation("Tip"),
 *   default_step = "order_information",
 *   wrapper_element = "fieldset",
 * )
 */
class TipCheckoutPane extends CheckoutPaneBase {

  /**
   * The inline form manager.
   *
   * @var \Drupal\commerce\InlineFormManager
   */
  protected InlineFormManager $inlineFormManager;

  /**
   * The router match.
   *
   * @var \Drupal\Core\Routing\RouteMatchInterface
   */
  protected RouteMatchInterface $routeMatch;

  /**
   * Constructs a new TipCheckoutPane object.
   *
   * @param array $configuration
   *   A configuration array containing information about the plugin instance.
   * @param string $plugin_id
   *   The plugin_id for the plugin instance.
   * @param mixed $plugin_definition
   *   The plugin implementation definition.
   * @param \Drupal\commerce_checkout\Plugin\Commerce\CheckoutFlow\CheckoutFlowInterface $checkout_flow
   *   The parent checkout flow.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\commerce\InlineFormManager $inline_form_manager
   *   The inline form manager.
   * @param \Drupal\Core\Routing\RouteMatchInterface $router_match
   *   The router match.
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow, EntityTypeManagerInterface $entity_type_manager, InlineFormManager $inline_form_manager, RouteMatchInterface $router_match) {
    parent::__construct($configuration, $plugin_id, $plugin_definition, $checkout_flow, $entity_type_manager);
    $this->inlineFormManager = $inline_form_manager;
    $this->routeMatch = $router_match;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition, CheckoutFlowInterface $checkout_flow = NULL) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $checkout_flow,
      $container->get('entity_type.manager'),
      $container->get('plugin.manager.commerce_inline_form'),
      $container->get('current_route_match')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationSummary() {
    $summary = [];
    if (empty($this->configuration['tip_description']['value'])) {
      $summary[] = $this->t('Tip description: Off');
    }
    else {
      $summary[] = $this->t('Tip description: On');
    }

    return implode('<br>', $summary);
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration() {
    return [
      'tip_description' => [
        'value' => '',
        'format' => 'plain_text',
      ],
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildConfigurationForm($form, $form_state);
    $form['tip_description'] = [
      '#type' => 'text_format',
      '#title' => t('Tip Description'),
      '#description' => t('Shown at the top of checkout pane.'),
      '#default_value' => $this->configuration['tip_description']['value'],
      '#format' => $this->configuration['tip_description']['format'],
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state) {
    parent::submitConfigurationForm($form, $form_state);
    if (!$form_state->getErrors()) {
      $values = $form_state->getValue($form['#parents']);
      $this->configuration['tip_description'] = $values['tip_description'];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function buildPaneForm(array $pane_form, FormStateInterface $form_state, array &$complete_form) {
    $step = $this->routeMatch->getParameter('step');
    if ($step && in_array($step, ['order_information', 'review'])) {
      $configuration = [
        'order_id' => $this->order->id(),
        'tip_description' => $this->configuration['tip_description'],
      ];
      $inline_form = $this->inlineFormManager->createInstance('commerce_tip_inline_form', $configuration);
      $pane_form['form'] = [
        '#parents' => array_merge($pane_form['#parents'], ['form']),
      ];
      $pane_form['form'] = $inline_form->buildInlineForm($pane_form['form'], $form_state);
    }
    else {
      $pane_form['form'] = [
        '#type' => 'label',
        '#title' => t('Commerce Tip only support step "order information" or "review".'),
      ];
    }
    return $pane_form;
  }

}
